from typing import Final


class AuthStatus:
    MachineId: Final[str] = "mi"
    SignedUp: Final[str] = "sign"
    Confirmed: Final[str] = "conf"
    Band: Final[str] = "band"
    Disabled: Final[str] = "dis"
